@@ -63,20 +63,15 @@ GtkWidget *statusbar;
 GtkWidget *notebook;
 GtkWidget *chat = NULL;
 
-static const GamesScoresCategory scorecats[] = { {"4.0", N_("Beginner")},
-{"3.0", N_("Slow")},
-{"2.0", N_("gnibbles|Medium")},
-{"1.0", N_("Fast")},
-{"4.1", N_("Beginner with Fakes")},
-{"3.1", N_("Slow with Fakes")},
-{"2.1", N_("Medium with Fakes")},
-{"1.1", N_("Fast with Fakes")},
-GAMES_SCORES_LAST_CATEGORY
-};
-static const GamesScoresDescription scoredesc = { scorecats,
-  "4.0",
-  "gnibbles",
-  GAMES_SCORES_STYLE_PLAIN_DESCENDING
+static const GamesScoresCategory scorecats[] = {
+{ "4.0", NC_("game speed", "Beginner")            },
+{ "3.0", NC_("game speed", "Slow")                },
+{ "2.0", NC_("game speed", "Medium")              },
+{ "1.0", NC_("game speed", "Fast")                },
+{ "4.1", NC_("game speed", "Beginner with Fakes") },
+{ "3.1", NC_("game speed", "Slow with Fakes")     },
+{ "2.1", NC_("game speed", "Medium with Fakes")   },
+{ "1.1", NC_("game speed", "Fast with Fakes")     }
 };
 
 GamesScores *highscores;
@@ -1044,22 +1039,11 @@ main (int argc, char **argv)
   gboolean retval;
   GError *error = NULL;
 
-#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
-  /* If we're going to use gnome-vfs, we need to init threads before
-   * calling any glib functions.
-   */
-  g_thread_init (NULL);
-#endif
-  
   if (!games_runtime_init ("gnibbles"))
     return 1;
 
   setgid_io_init ();
 
-  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
-
   context = g_option_context_new (NULL);
 
 #if GLIB_CHECK_VERSION (2, 12, 0)
@@ -1082,7 +1066,11 @@ main (int argc, char **argv)
   gtk_window_set_default_icon_name ("gnome-gnibbles");
   srand (time (NULL));
 
-  highscores = games_scores_new (&scoredesc);
+  highscores = games_scores_new ("gnibbles",
+                                 scorecats, G_N_ELEMENTS (scorecats),
+                                 "game speed", NULL,
+                                 0 /* default category */,
+                                 GAMES_SCORES_STYLE_PLAIN_DESCENDING);
 
   games_conf_initialise ("Gnibbles");
 
