@@ -19,23 +19,25 @@
  * For more details see the file COPYING.
  */
 
+#include <config.h>
 #include "field.h"
 #include "blocks.h"
 #include "renderer.h"
 
+#include <clutter-cairo/clutter-cairo.h>
 #include <libgames-support/games-clutter-embed.h>
 
 #define FONT "Sans Bold"
 
 Field::Field():
 	BlockOps(),
-	buffer(NULL),
 	background(NULL),
+	foreground(NULL),
 	showPause(false),
 	showGameOver(false),
 	backgroundImage(NULL),
 	backgroundImageTiled(false),
-useBGImage(false),
+	useBGImage(false),
 	backgroundColor(NULL)
 {
 	themeID = 0;
@@ -45,7 +47,8 @@ useBGImage(false),
 	w = games_clutter_embed_new();
 
 	g_signal_connect (w, "configure_event", G_CALLBACK (configure), this);
-	/* We do our own double-buffering. */
+
+	/* I don't know if this helps or not FIXME */
 	gtk_widget_set_double_buffered(w, FALSE);
 
 	gtk_widget_set_size_request (w, COLUMNS*190/LINES, 190);
@@ -55,37 +58,65 @@ useBGImage(false),
 
 Field::~Field()
 {
-	if (buffer)
-		cairo_surface_destroy(buffer);
 	if (background)
-		cairo_surface_destroy(background);
+		clutter_actor_destroy(background);
 
 	if (renderer)
 		delete renderer;
 }
 
 void
-Field::rescaleBackground ()
+Field::rescaleField ()
 {
+	ClutterActor *stage;
 	cairo_t *bg_cr;
-	cairo_t *tmp_cr;
 
-	if (!buffer)
-		return;
+	if (background) {
+		clutter_actor_set_size (CLUTTER_ACTOR(background),
+					w->allocation.width,
+					w->allocation.height);
+		clutter_cairo_surface_resize (CLUTTER_CAIRO(background),
+					      w->allocation.width,
+					      w->allocation.height);
+	} else {
+		background = clutter_cairo_new (w->allocation.width,
+						w->allocation.height);
+		stage = games_clutter_embed_get_stage (GAMES_CLUTTER_EMBED (w));
+		/*FIXMEjclinton: eventually allow solid color background
+		 * for software rendering case */
+		ClutterColor stage_color = { 0x61, 0x64, 0x8c, 0xff };
+		clutter_stage_set_color (CLUTTER_STAGE (stage),
+					 &stage_color);
+		clutter_group_add (CLUTTER_GROUP (stage),
+				   background);
+		clutter_actor_set_position (CLUTTER_ACTOR(background),
+					    0, 0);
+	}
 
-	tmp_cr = cairo_create (buffer);
+	if (foreground) {
+		clutter_actor_set_size (CLUTTER_ACTOR(foreground),
+					w->allocation.width,
+					w->allocation.height);
+		clutter_cairo_surface_resize (CLUTTER_CAIRO(foreground),
+					      w->allocation.width,
+					      w->allocation.height);
+	} else {
+		foreground = clutter_cairo_new (w->allocation.width,
+						w->allocation.height);
+		stage = games_clutter_embed_get_stage (GAMES_CLUTTER_EMBED (w));
+		clutter_group_add (CLUTTER_GROUP (stage),
+				   foreground);
+		clutter_actor_set_position (CLUTTER_ACTOR(foreground),
+					    0, 0);
+		clutter_actor_raise (CLUTTER_ACTOR(foreground),
+				     CLUTTER_ACTOR(background));
+	}
 
-	if (background)
-		cairo_surface_destroy(background);
 
-	background =  cairo_surface_create_similar (cairo_get_target (tmp_cr),
-						    CAIRO_CONTENT_COLOR,
-						    w->allocation.width,
-						    w->allocation.height);
-
-	cairo_destroy (tmp_cr);
-
-	bg_cr = cairo_create (background);
+	bg_cr = clutter_cairo_create (CLUTTER_CAIRO(background));
+	cairo_set_operator (bg_cr, CAIRO_OPERATOR_CLEAR);
+	cairo_paint(bg_cr);
+	cairo_set_operator (bg_cr, CAIRO_OPERATOR_OVER);
 
 	if (useBGImage && backgroundImage) {
 		gdouble xscale, yscale;
@@ -93,8 +124,8 @@ Field::rescaleBackground ()
 
 		/* FIXME: This doesn't handle tiled backgrounds in the obvious way. */
 		gdk_cairo_set_source_pixbuf(bg_cr, backgroundImage, 0, 0);
-		xscale = 1.0*gdk_pixbuf_get_width (backgroundImage)/width;
-		yscale = 1.0*gdk_pixbuf_get_height (backgroundImage)/height;
+		xscale = 1.0*gdk_pixbuf_get_width (backgroundImage)/w->allocation.width;
+		yscale = 1.0*gdk_pixbuf_get_height (backgroundImage)/w->allocation.height;
 		cairo_matrix_init_scale (&m, xscale, yscale);
 		cairo_pattern_set_matrix (cairo_get_source (bg_cr), &m);
 	} else if (backgroundColor)
@@ -109,53 +140,24 @@ Field::rescaleBackground ()
 	redraw ();
 }
 
+void
+Field::rescaleBlockCache ()
+{
+	return;
+}
+
 gboolean
 Field::configure(GtkWidget *widget, GdkEventConfigure *event, Field *field)
 {
-	cairo_t *cr;
-
 	field->width = widget->allocation.width;
 	field->height = widget->allocation.height;
 
-	cr = gdk_cairo_create (widget->window);
-
-	if (field->buffer)
-		cairo_surface_destroy(field->buffer);
-
-	// backing buffer
-	field->buffer =  cairo_surface_create_similar (cairo_get_target (cr),
-						       CAIRO_CONTENT_COLOR,
-						       widget->allocation.width,
-						       widget->allocation.height);
-
-	cairo_destroy (cr);
-
-
-	field->rescaleBackground ();
+	field->rescaleField ();
+	field->rescaleBlockCache ();
 
 	return TRUE;
 }
 
-void
-Field::draw (gint x, gint y, gint wd, gint ht)
-{
-	cairo_t *cr;
-
-	cr = gdk_cairo_create (w->window);
-	
-	cairo_set_source_surface (cr, buffer, 0, 0);
-	cairo_rectangle (cr, x, y, wd, ht);
-	cairo_fill (cr);
-	
-	cairo_destroy (cr);
-}
-
-void
-Field::draw (void)
-{
-  draw (0, 0, width, height);
-}
-
 void
 Field::drawMessage(cairo_t *cr, const char *msg)
 {
@@ -179,7 +181,7 @@ Field::drawMessage(cairo_t *cr, const char *msg)
 	pango_layout_get_size(dummy_layout, &lw, &lh);
 	g_object_unref(dummy_layout);
 
-	// desired height : lh = widget width * 0.9 : lw 
+	// desired height : lh = widget width * 0.9 : lw
 	pango_font_description_set_absolute_size(desc, ((float) lh / lw) * PANGO_SCALE * width * 0.8);
 	pango_layout_set_font_description(layout, desc);
 	pango_font_description_free(desc);
@@ -203,22 +205,24 @@ void
 Field::redraw()
 {
 	cairo_t *cr;
-	
-	g_return_if_fail(buffer);
 
 	generateTarget ();
 
+	cr = clutter_cairo_create (CLUTTER_CAIRO(foreground));
+	cairo_set_operator (cr, CAIRO_OPERATOR_CLEAR);
+	cairo_paint(cr);
+	cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
+
 	if (rendererTheme != themeID) {
 
-	if (renderer)
-		delete renderer;
+		if (renderer)
+			delete renderer;
 
-	renderer = rendererFactory (themeID, buffer, background, field, 
-			     COLUMNS, LINES, width, height);
-	rendererTheme = themeID;
+		renderer = rendererFactory (themeID, foreground, field,
+				     COLUMNS, LINES, width, height);
+		rendererTheme = themeID;
 	} else {
-		renderer->setTarget (buffer);
-		renderer->setBackground (background);
+		renderer->setTarget (foreground);
 		renderer->data = field;
 		renderer->width = COLUMNS;
 		renderer->height = LINES;
@@ -228,16 +232,12 @@ Field::redraw()
 
 	renderer->render ();
 
-	cr = cairo_create(buffer);
-
 	if (showPause)
 		drawMessage(cr, _("Paused"));
 	else if (showGameOver)
 		drawMessage(cr, _("Game Over"));
 
 	cairo_destroy(cr);
-
-	draw ();
 }
 
 void
@@ -247,7 +247,7 @@ Field::setBackground(GdkPixbuf *bgImage)//, bool tiled)
 	useBGImage = true;
 //	backgroundImageTiled = tiled;
 
-	rescaleBackground ();
+	rescaleField ();
 }
 
 void
@@ -260,7 +260,7 @@ Field::setBackground(GdkColor *bgColor)
 	}
 	useBGImage = false;
 
-	rescaleBackground ();
+	rescaleField ();
 }
 
 void
@@ -295,7 +295,7 @@ Field::hideGameOverMessage()
 	redraw();
 }
 
-void 
+void
 Field::setTheme (gint id)
 {
 	themeID = id;
