@@ -62,10 +62,19 @@
 #define DEFAULT_WIDTH 320
 #define DEFAULT_HEIGHT 240
 
-/* i18n in-game numbers, replaceable with single-character local ideograms. */
-static const char *translatable_number[10] =
-  { N_("0"), N_("1"), N_("2"), N_("3"), N_("4"), N_("5"), N_("6"), N_("7"),
-N_("8"), N_("9") };
+static const char *translatable_number[10] = {
+  /* Translators: in-game numbers, replaceable with single-character local ideograms */
+  NC_("number", "0"),
+  NC_("number", "1"),
+  NC_("number", "2"),
+  NC_("number", "3"),
+  NC_("number", "4"),
+  NC_("number", "5"),
+  NC_("number", "6"),
+  NC_("number", "7"),
+  NC_("number", "8"),
+  NC_("number", "9")
+};
 
 static GtkWidget *window;
 static GtkWidget *statusbar;
@@ -73,17 +82,12 @@ static GtkWidget *space;
 static GtkWidget *timer;
 static GdkGC *bg_gc;
 
-static const GamesScoresCategory scorecats[] = { {"2x2", N_("2\303\2272")},
-{"3x3", N_("3\303\2273")},
-{"4x4", N_("4\303\2274")},
-{"5x5", N_("5\303\2275")},
-{"6x6", N_("6\303\2276")},
-GAMES_SCORES_LAST_CATEGORY
-};
-static const GamesScoresDescription scoredesc = { scorecats,
-  "3x3",
-  "gnotravex",
-  GAMES_SCORES_STYLE_TIME_ASCENDING
+static const GamesScoresCategory scorecats[] = {
+  { "2x2", N_("2\303\2272") },
+  { "3x3", N_("3\303\2273") },
+  { "4x4", N_("4\303\2274") },
+  { "5x5", N_("5\303\2275") },
+  { "6x6", N_("6\303\2276") }
 };
 
 static GamesScores *highscores;
@@ -416,22 +420,11 @@ main (int argc, char **argv)
   EggSMClient *sm_client;
 #endif /* WITH_SMCLIENT */
 
-#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
-  /* If we're going to use gnome-vfs, we need to init threads before
-   * calling any glib functions.
-   */
-  g_thread_init (NULL);
-#endif
-
   if (!games_runtime_init ("gnotravex"))
     return 1;
 
   setgid_io_init ();
 
-  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
-
   context = g_option_context_new (NULL);
 #if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
@@ -455,7 +448,11 @@ main (int argc, char **argv)
 
   games_conf_initialise (APPNAME);
 
-  highscores = games_scores_new (&scoredesc);
+  highscores = games_scores_new ("gnotravex",
+                                 scorecats, G_N_ELEMENTS (scorecats),
+                                 NULL, NULL,
+                                 1 /* default category */,
+                                 GAMES_SCORES_STYLE_TIME_ASCENDING);
 
   games_stock_init ();
 
@@ -861,10 +858,10 @@ gui_draw_socket (GdkPixmap * target, GtkStateType state, gint xadd, gint yadd)
 void
 gui_draw_number (cairo_t * context, gdouble x, gdouble y, guint number, gdouble *colour)
 {
-  gchar *text;
+  const gchar *text;
   cairo_text_extents_t extents;
 
-  text = _(translatable_number[number]);
+  text = g_dpgettext2 (NULL, "number", translatable_number[number]);
 
   cairo_set_source_rgba (context, colour[0] / 255.0, colour[1] / 255.0,
                          colour[2] / 255.0, colour[3] / 255.0);
